
#include <QGraphicsGridLayout>
#include <QGraphicsLinearLayout>
#include <QGraphicsProxyWidget>
#include <QGraphicsSceneMouseEvent>

#include <QApplication>
#include <QEvent>
#include <QPoint>
#include <QKeyEvent>
#include <QRect>
#include <QDesktopWidget>
#include <QPainter>

#include "clippinglabel.h"
#include "WPData.h"
#include "wppagegraphicslistitem.h"
#include "WPNetworkEngine.h"
#include "MDragWidget.h"
#include "busyindicator.h"

WPPageGraphicsListItem::WPPageGraphicsListItem(const WPPageGraphicsList& aList, WPPage aPage, BusyIndicator& aBusyIndicator, ThemeData& aThemeData)
    : WPGraphicsListItem(aBusyIndicator, aThemeData)
    , iList(aList)
    , iPage(aPage)
{
    setObjectName(QString::fromLatin1("WPPageListItem"));
    iDate = aPage->GetShortLocalTimeString(); 
    setMinimumHeight(ItemMinimumHeight);
}

WPPageGraphicsListItem::~WPPageGraphicsListItem()
{
}

WPPage WPPageGraphicsListItem::GetPage() 
{
    return iPage;
}

void WPPageGraphicsListItem::paintContent(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/, QWidget* /*widget*/)
{   
    painter->setPen(Qt::black);

    // TODO: Add elided texts
    painter->setFont(iList.titleFont());
    painter->drawText(QPoint(contentXOffset(), 24), iTitle);
    painter->setFont(iList.authorFont());
    painter->drawText(QPoint(contentXOffset(), 56), "by " + iPage->iWpAuthorDisplayName);
    painter->setFont(iList.infoFont());
    painter->drawText(QPoint(contentXOffset(), 112), iDate);
}

bool WPPageGraphicsListItem::IsBusy()
{
    return iPage->IsBusy();
}

bool WPPageGraphicsListItem::HasError()
{
	return iPage->iError;
}

void WPPageGraphicsListItem::handleGeomeryChange()
{
	calculateElidedTexts();
}

void WPPageGraphicsListItem::calculateElidedTexts()
{
    QFontMetrics titleFm(iList.titleFont());
    iTitle = titleFm.elidedText(iPage->iTitle, Qt::ElideRight, int(width()) - 50);
}

