#include "wppostgraphicslistitem.h"
#include "WPData.h"

#include <QPoint>
#include <QRect>
#include <QPainter>

WPPostGraphicsListItem::WPPostGraphicsListItem(const WPPostGraphicsList& aList, WPPost aPost, BusyIndicator& aBusyIndicator, ThemeData& aThemeData)
    : WPGraphicsListItem(aBusyIndicator, aThemeData)
    , iList(aList)
    , iPost(aPost)
{
    setObjectName(QString::fromLatin1("WPPostListItem"));
    iDate = aPost->GetShortLocalTimeString(); 
    setMinimumHeight(ItemMinimumHeight);
}

WPPostGraphicsListItem::~WPPostGraphicsListItem()
{
}

WPPost WPPostGraphicsListItem::GetPost() const
{
    return iPost;
}

void WPPostGraphicsListItem::paintContent(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/, QWidget* /*widget*/)
{
    painter->setPen(Qt::black);

    // TODO: Add elided texts
    painter->setFont(iList.titleFont());
    painter->drawText(QPoint(contentXOffset(), 24), iTitle);
    painter->setFont(iList.authorFont());
    painter->drawText(QPoint(contentXOffset(), 56), "by " + iPost->iWpAuthorDisplayName);
    painter->setFont(iList.infoFont());
    painter->drawText(QPoint(contentXOffset(), 112), iDate);
    painter->drawText(QPoint(contentXOffset(), 132), tr("0 comments")); // todo comments.
}

bool WPPostGraphicsListItem::IsBusy()
{
    return iPost->IsBusy();
}

bool WPPostGraphicsListItem::HasError()
{
    return iPost->iError;
}

void WPPostGraphicsListItem::handleGeomeryChange()
{
    calculateElidedTexts();
}

void WPPostGraphicsListItem::calculateElidedTexts()
{
    QFontMetrics titleFm(iList.titleFont());
    iTitle = titleFm.elidedText(iPost->iTitle, Qt::ElideRight, int(width()) - 50);
}
